from django.core.exceptions import PermissionDenied

def role_required(allowed_roles):
    """ Restrict access to views based on user roles. """
    def decorator(view_func):
        def wrapper(request, *args, **kwargs):
            if not request.user.is_authenticated or request.user.role not in allowed_roles:
                raise PermissionDenied  # 403 Forbidden
            return view_func(request, *args, **kwargs)
        return wrapper
    return decorator
