from django.shortcuts import render, get_object_or_404, redirect
from django.contrib.auth.decorators import login_required
from .models import Event
from .forms import EventForm

# ✅ View All Events (Homepage)
def event_list(request):
    events = Event.objects.all().order_by('date')
    return render(request, "events/event_list.html", {"events": events})

# ✅ View a Single Event
def event_detail(request, event_id):
    event = get_object_or_404(Event, id=event_id)
    return render(request, "events/event_detail.html", {"event": event})

# ✅ Create an Event (Only for Community Leaders)
@login_required
def create_event(request):
    if request.user.role != "community_leader":  # Restrict access
        return redirect("event_list")  # Redirect unauthorized users
    
    if request.method == "POST":
        form = EventForm(request.POST)
        if form.is_valid():
            event = form.save(commit=False)
            event.organizer = request.user  # Set the event creator
            event.save()
            return redirect("event_list")
    else:
        form = EventForm()
    
    return render(request, "events/event_form.html", {"form": form})
